==> web-instant-0.3.0.tgz: package/test/create.spec.js <==
import test from 'ava';

import temp from 'temp';
import isObject from 'lodash/isObject';

import {
  exec,
  ls,
} from 'shelljs';

import {
  configPackageSync,
  versionControlSync,
  copyTemplates,
} from '../src/setup';

temp.track();

test('should copy template successfully', async t => {
  // Create temp path for testing
  const path = temp.mkdirSync('project');

  await copyTemplates(path)
  const { stdout: fileList } = ls(path);

  t.is(fileList.includes('src'), true);
  t.is(fileList.includes('webpack.config.babel.js'), true);
});

// it is not expected to test on remote server like CI since there is no git account configurated
test('should contain initial commit with version control', t => {
  const { stdout: gitUserName } = exec('git config user.name');

  const gitConfigurated = gitUserName.trim() === 'George Jor';

  if (!gitConfigurated) {
    t.pass();
    return;
  }

  // Create temp path for testing
  const path = temp.mkdirSync('project');
  process.chdir(path);

  // Create a dummy file for `git add .`
  exec('echo "" > dummy.txt');

  versionControlSync();

  const { stdout: gitStatus } = exec('git status');
  const { stdout: gitLog } = exec('git log --pretty=oneline --abbrev-commit -1');

  t.is(gitStatus.includes('On branch master'), true);
  t.is(gitLog.includes('Initial commit'), true);

  t.pass();
});

test('should create and modify package.json successfully', t => {
  // Create temp path for testing
  const path = temp.mkdirSync('project');
  process.chdir(path);

  configPackageSync();

  /* eslint-disable global-require */
  const targetFile = require(`${path}/package.json`);
  /* eslint-enable */

  t.is(isObject(targetFile), true);

  t.deepEqual(targetFile.scripts, {
    lint: 'eslint src',
    build: 'NODE_ENV=production web-instant build',
    start: 'web-instant start',
  });

  t.is(targetFile.license, 'UNLICENSED');

  t.deepEqual(targetFile.eslintConfig, {
    extends: 'eslint-config-airbnb',
    parser: 'babel-eslint',
  });

  t.deepEqual(targetFile.babel, {
    presets: ['es2015', 'stage-2', 'react', 'react-optimize'],
  });

  t.pass();
});

==> web-instant-0.5.1.tgz: package/test/create.spec.js <==
import test from 'ava';

import temp from 'temp';
import isObject from 'lodash/isObject';

import {
  exec,
  ls,
} from 'shelljs';

import {
  configPackageSync,
  versionControlSync,
  copyTemplates,
} from '../src/setup';

temp.track();

test('should copy template successfully', async t => {
  // Create temp path for testing
  const path = temp.mkdirSync('project');

  await copyTemplates(path);
  const { stdout: fileList } = ls(path);

  t.is(fileList.includes('src'), true);
  t.is(fileList.includes('webpack.config.babel.js'), true);
});

// it is not expected to test on remote server like CI since there is no git account configurated
test('should contain initial commit with version control', t => {
  const { stdout: gitUserName } = exec('git config user.name');

  const gitConfigurated = gitUserName.trim() === 'George Jor';

  if (!gitConfigurated) {
    t.pass();
    return;
  }

  // Create temp path for testing
  const path = temp.mkdirSync('project');
  process.chdir(path);

  // Create a dummy file for `git add .`
  exec('echo "" > dummy.txt');

  versionControlSync();

  const { stdout: gitStatus } = exec('git status');
  const { stdout: gitLog } = exec('git log --pretty=oneline --abbrev-commit -1');

  t.is(gitStatus.includes('On branch master'), true);
  t.is(gitLog.includes('Initial commit'), true);

  t.pass();
});

test('should create and modify package.json successfully', t => {
  // Create temp path for testing
  const path = temp.mkdirSync('project');
  process.chdir(path);

  configPackageSync();

  /* eslint-disable global-require */
  const targetFile = require(`${path}/package.json`);
  /* eslint-enable */

  t.is(isObject(targetFile), true);

  t.deepEqual(targetFile.scripts, {
    lint: 'eslint src',
    build: 'NODE_ENV=production web-instant build',
    start: 'web-instant start',
  });

  t.is(targetFile.license, 'UNLICENSED');

  t.deepEqual(targetFile.eslintConfig, {
    extends: 'eslint-config-airbnb',
    parser: 'babel-eslint',
  });

  t.deepEqual(targetFile.babel, {
    presets: ['es2015', 'stage-2', 'react', 'react-optimize'],
  });

  t.pass();
});
